@@ -3,7 +3,7 @@ use warnings;
 
 package Pantry::App::Command::create;
 # ABSTRACT: Implements pantry create subcommand
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use Pantry::App -command;
 use autodie;
@@ -11,46 +11,26 @@ use autodie;
 use namespace::clean;
 
 sub abstract {
-  return 'create items in a pantry (nodes, roles, etc.)';
+  return 'Create items in a pantry (nodes, roles, etc.)';
 }
 
-sub options {
-  return;
+sub command_type {
+  return 'CREATE';
 }
 
-sub validate {
-  my ($self, $opts, $args) = @_;
-  my ($type, $name) = @$args;
-
-  # validate type
-  if ( ! length $type ) {
-    $self->usage_error( "This command requires a target type and name" );
-  }
-  elsif ( $type ne 'node' ) {
-    $self->usage_error( "Invalid type '$type'" );
-  }
-
-  # validate name
-  if ( ! length $name ) {
-    $self->usage_error( "This command requires the name for the thing to create" );
-  }
-
-  return;
+sub valid_types {
+  return qw/node/
 }
 
-sub execute {
-  my ($self, $opt, $args) = @_;
+sub _create_node {
+  my ($self, $opt, $name) = @_;
 
-  my ($type, $name) = splice(@$args, 0, 2);
-
-  if ( $type eq 'node' ) {
-    my $node = $self->pantry->node( $name );
-    if ( -e $node->path ) {
-      $self->usage_error( "Node '$name' already exists" );
-    }
-    else {
-      $node->save;
-    }
+  my $node = $self->pantry->node( $name );
+  if ( -e $node->path ) {
+    $self->usage_error( "Node '$name' already exists" );
+  }
+  else {
+    $node->save;
   }
 
   return;
@@ -70,7 +50,7 @@ Pantry::App::Command::create - Implements pantry create subcommand
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
